==> haskell-hspec-core-2.11.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-core
version:              2.11.1
visibility:           public
id:                   hspec-core-2.11.1-FEtocjFrEnV9tzCy4gGXD9
key:                  hspec-core-2.11.1-FEtocjFrEnV9tzCy4gGXD9
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  42cbb3f4b12e380a76dec7ddcec46dee
exposed:              True
exposed-modules:
    Test.Hspec.Core.Format Test.Hspec.Core.Formatters
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.Runner Test.Hspec.Core.Spec Test.Hspec.Core.Util

hidden-modules:
    GetOpt.Declarative GetOpt.Declarative.Environment
    GetOpt.Declarative.Interpret GetOpt.Declarative.Types
    GetOpt.Declarative.Util NonEmpty Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Definition Test.Hspec.Core.Config.Options
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Pretty
    Test.Hspec.Core.Formatters.Pretty.Parser
    Test.Hspec.Core.Formatters.Pretty.Parser.Parser
    Test.Hspec.Core.Formatters.Pretty.Unicode
    Test.Hspec.Core.Formatters.V1.Free
    Test.Hspec.Core.Formatters.V1.Internal
    Test.Hspec.Core.Formatters.V1.Monad Test.Hspec.Core.QuickCheckUtil
    Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Runner.JobQueue
    Test.Hspec.Core.Runner.PrintSlowSpecItems
    Test.Hspec.Core.Runner.Result Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
    Test.Hspec.Core.Tree Control.Concurrent.Async Data.Algorithm.Diff
    Paths_hspec_core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-core-2.11.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-core-2.11.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-core-2.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-core
hs-libraries:         HShspec-core-2.11.1-FEtocjFrEnV9tzCy4gGXD9
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    QuickCheck-2.15.0.1-KEw9aoMxM6q6i8cfYYug2V
    ansi-terminal-1.0.2-vFVvoY6zrCCEYOqozRT68 array-0.5.4.0
    base-4.17.2.1 call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    haskell-lexer-1.1.2-K4xn3msH1rqDmzpJS8M1s1
    hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568 process-1.6.18.0
    quickcheck-io-0.2.0-A04TjyVDOc14LpfcISOtsm
    random-1.2.1.3-2Hw42CquWtj55joOjOmzRr stm-2.5.1.0
    tf-random-0.5-BwhTaLcWWvP52EoUdC06Jw time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html:         /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-core-2.11.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-core
version:              2.11.1
visibility:           public
id:                   hspec-core-2.11.1-EEUB5Tel7FBJZKJ4IZlh7F
key:                  hspec-core-2.11.1-EEUB5Tel7FBJZKJ4IZlh7F
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  d99aa851b64033685704256ff9701da9
exposed:              True
exposed-modules:
    Test.Hspec.Core.Format Test.Hspec.Core.Formatters
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.Runner Test.Hspec.Core.Spec Test.Hspec.Core.Util

hidden-modules:
    GetOpt.Declarative GetOpt.Declarative.Environment
    GetOpt.Declarative.Interpret GetOpt.Declarative.Types
    GetOpt.Declarative.Util NonEmpty Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Definition Test.Hspec.Core.Config.Options
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Pretty
    Test.Hspec.Core.Formatters.Pretty.Parser
    Test.Hspec.Core.Formatters.Pretty.Parser.Parser
    Test.Hspec.Core.Formatters.Pretty.Unicode
    Test.Hspec.Core.Formatters.V1.Free
    Test.Hspec.Core.Formatters.V1.Internal
    Test.Hspec.Core.Formatters.V1.Monad Test.Hspec.Core.QuickCheckUtil
    Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Runner.JobQueue
    Test.Hspec.Core.Runner.PrintSlowSpecItems
    Test.Hspec.Core.Runner.Result Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
    Test.Hspec.Core.Tree Control.Concurrent.Async Data.Algorithm.Diff
    Paths_hspec_core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-core-2.11.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-core-2.11.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-core-2.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-core
hs-libraries:         HShspec-core-2.11.1-EEUB5Tel7FBJZKJ4IZlh7F
depends:
    HUnit-1.6.2.0-9X1R1uFIABDFmOEozkgarM
    QuickCheck-2.15.0.1-7dsjbuPrJB87A5nQdB1dNE
    ansi-terminal-1.0.2-FTkVGNDxEfy5jKOkYDwQmU array-0.5.4.0
    base-4.17.2.1 call-stack-0.4.0-wdz1639SOC9HqySMka9DA
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    haskell-lexer-1.1.2-K4xn3msH1rqDmzpJS8M1s1
    hspec-expectations-0.8.3-HoU1SHmaxn0CpyNDindE4g process-1.6.18.0
    quickcheck-io-0.2.0-HTlO2fawHzUGb4fyk4gwPy
    random-1.2.1.3-LY8g0he9kPzH0WCF9vQLty stm-2.5.1.0
    tf-random-0.5-KPyHCrIyfBU6GsfZBE8p14 time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html:         /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
